Source-Changes-HG archive

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index][Old Index]

[src/trunk]: src/usr.bin/ftp Back to using 'RFC xxxx' instead of 'RFCxxxx'



details:   https://anonhg.NetBSD.org/src/rev/0c5508ace90c
branches:  trunk
changeset: 752731:0c5508ace90c
user:      lukem <lukem%NetBSD.org@localhost>
date:      Fri Mar 05 07:41:10 2010 +0000

description:
Back to using 'RFC xxxx' instead of 'RFCxxxx'

diffstat:

 usr.bin/ftp/fetch.c |  18 +++++++++---------
 usr.bin/ftp/ftp.1   |  34 +++++++++++++++++-----------------
 usr.bin/ftp/ftp.c   |   8 ++++----
 usr.bin/ftp/util.c  |  16 ++++++++--------
 4 files changed, 38 insertions(+), 38 deletions(-)

diffs (272 lines):

diff -r 3a7e4c146eae -r 0c5508ace90c usr.bin/ftp/ftp.1
--- a/usr.bin/ftp/ftp.1 Fri Mar 05 06:47:58 2010 +0000
+++ b/usr.bin/ftp/ftp.1 Fri Mar 05 07:41:10 2010 +0000
@@ -1,6 +1,6 @@
-.\"    $NetBSD: ftp.1,v 1.130 2009/07/11 18:35:48 joerg Exp $
+.\"    $NetBSD: ftp.1,v 1.131 2010/03/05 07:41:10 lukem Exp $
 .\"
-.\" Copyright (c) 1996-2008 The NetBSD Foundation, Inc.
+.\" Copyright (c) 1996-2010 The NetBSD Foundation, Inc.
 .\" All rights reserved.
 .\"
 .\" This code is derived from software contributed to The NetBSD Foundation
@@ -57,7 +57,7 @@
 .\"
 .\"    @(#)ftp.1       8.3 (Berkeley) 10/9/94
 .\"
-.Dd May 10, 2008
+.Dd March 5, 2010
 .Dt FTP 1
 .Os
 .Sh NAME
@@ -777,7 +777,7 @@
 .Dq stream .
 .It Ic modtime Ar remote-file
 Show the last modification time of the file on the remote machine, in
-.Li RFC2822
+.Li RFC 2822
 format.
 .It Ic more Ar file
 A synonym for
@@ -998,7 +998,7 @@
 servers are required to support the
 .Dv PASV
 command by
-.Li RFC1123 ,
+.Li RFC 1123 ,
 some do not.)
 .It Ic pdir Op Ar remote-path
 Perform
@@ -1591,7 +1591,7 @@
 The default transfer type is binary.
 .Pp
 In order to be compliant with
-.Li RFC3986 ,
+.Li RFC 3986 ,
 .Nm
 interprets the
 .Ar path
@@ -1644,7 +1644,7 @@
 .Sq Li \&% Ns Ar XX
 codes
 (per
-.Li RFC3986 )
+.Li RFC 3986 )
 within the path components are decoded, with
 .Ar XX
 representing a character code in hexadecimal.
@@ -2285,7 +2285,7 @@
 or
 .Sq / ) ,
 encode them with
-.Li RFC3986
+.Li RFC 3986
 .Sq Li \&% Ns Ar XX
 encoding.
 .Pp
@@ -2330,23 +2330,23 @@
 .Nm
 attempts to be compliant with:
 .Bl -tag -offset indent -width 8n
-.It Li RFC0959
+.It Li RFC 959
 .Em File Transfer Protocol
-.It Li RFC1123
+.It Li RFC 1123
 .Em Requirements for Internet Hosts - Application and Support
-.It Li RFC1635
+.It Li RFC 1635
 .Em How to Use Anonymous FTP
-.It Li RFC2389
+.It Li RFC 2389
 .Em Feature negotiation mechanism for the File Transfer Protocol
-.It Li RFC2428
+.It Li RFC 2428
 .Em FTP Extensions for IPv6 and NATs
-.It Li RFC2616
+.It Li RFC 2616
 .Em Hypertext Transfer Protocol -- HTTP/1.1
-.It Li RFC2822
+.It Li RFC 2822
 .Em Internet Message Format
-.It Li RFC3659
+.It Li RFC 3659
 .Em Extensions to FTP
-.It Li RFC3986
+.It Li RFC 3986
 .Em Uniform Resource Identifier (URI)
 .El
 .Sh HISTORY
diff -r 3a7e4c146eae -r 0c5508ace90c usr.bin/ftp/ftp.c
--- a/usr.bin/ftp/ftp.c Fri Mar 05 06:47:58 2010 +0000
+++ b/usr.bin/ftp/ftp.c Fri Mar 05 07:41:10 2010 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: ftp.c,v 1.159 2009/04/15 03:42:33 jld Exp $    */
+/*     $NetBSD: ftp.c,v 1.160 2010/03/05 07:41:10 lukem Exp $  */
 
 /*-
  * Copyright (c) 1996-2009 The NetBSD Foundation, Inc.
@@ -92,7 +92,7 @@
 #if 0
 static char sccsid[] = "@(#)ftp.c      8.6 (Berkeley) 10/27/94";
 #else
-__RCSID("$NetBSD: ftp.c,v 1.159 2009/04/15 03:42:33 jld Exp $");
+__RCSID("$NetBSD: ftp.c,v 1.160 2010/03/05 07:41:10 lukem Exp $");
 #endif
 #endif /* not lint */
 
@@ -805,7 +805,7 @@
                        }
                        (void)putc(c, dout);
                        bytes++;
-#if 0  /* this violates RFC0959 */
+#if 0  /* this violates RFC 959 */
                        if (c == '\r') {
                                (void)putc('\0', dout);
                                bytes++;
@@ -1152,7 +1152,7 @@
 
  abort:
                        /*
-                        * abort using RFC0959 recommended IP,SYNC sequence
+                        * abort using RFC 959 recommended IP,SYNC sequence
                         */
        if (! sigsetjmp(xferabort, 1)) {
                        /* this is the first call */
diff -r 3a7e4c146eae -r 0c5508ace90c usr.bin/ftp/fetch.c
--- a/usr.bin/ftp/fetch.c       Fri Mar 05 06:47:58 2010 +0000
+++ b/usr.bin/ftp/fetch.c       Fri Mar 05 07:41:10 2010 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: fetch.c,v 1.192 2010/03/04 21:40:53 lukem Exp $        */
+/*     $NetBSD: fetch.c,v 1.193 2010/03/05 07:41:10 lukem Exp $        */
 
 /*-
  * Copyright (c) 1997-2009 The NetBSD Foundation, Inc.
@@ -34,7 +34,7 @@
 
 #include <sys/cdefs.h>
 #ifndef lint
-__RCSID("$NetBSD: fetch.c,v 1.192 2010/03/04 21:40:53 lukem Exp $");
+__RCSID("$NetBSD: fetch.c,v 1.193 2010/03/05 07:41:10 lukem Exp $");
 #endif /* not lint */
 
 /*
@@ -281,7 +281,7 @@
 
 
 /*
  * Parse URL of form (per RFC3986):
  *     <type>://[<user>[:<password>]@]<host>[:<port>][/<path>]
  * Returns -1 if a parse error occurred, otherwise 0.
  * It's the caller's responsibility to url_decode() the returned
@@ -291,7 +291,7 @@
  * malloc(3)ed strings of the relevant section, and port to
  * the number given, or ftpport if ftp://, or httpport if http://.
  *
  * XXX: this is not totally RFC3986 compliant; <path> will have the
  * leading `/' unless it's an ftp:// URL, as this makes things easier
  * for file:// and http:// URLs.  ftp:// URLs have the `/' between the
  * host and the URL-path removed, but any additional leading slashes
@@ -394,7 +394,7 @@
 #ifdef INET6
                        /*
                         * Check if thost is an encoded IPv6 address, as per
-                        * RFC3986:
+                        * RFC 3986:
                         *      `[' ipv6-address ']'
                         */
        if (*thost == '[') {
@@ -1520,12 +1520,12 @@
                 * directories in one step.
                 *
                 * If we are dealing with an `ftp://host/path' URL
                 * (urltype is FTP_URL_T), then RFC3986 says we need to
                 * send a separate CWD command for each unescaped "/"
                 * in the path, and we have to interpret %hex escaping
                 * *after* we find the slashes.  It's possible to get
                 * empty components here, (from multiple adjacent
                 * slashes in the path) and RFC3986 says that we should
                 * still do `CWD ' (with a null argument) in such cases.
                 *
                 * Many ftp servers don't support `CWD ', so if there's an
@@ -1597,8 +1597,8 @@
                                                fprintf(stderr,
 "\n"
 "ftp: The `CWD ' command (without a directory), which is required by\n"
-"     RFC3986 to support the empty directory in the URL pathname (`//'),\n"
-"     conflicts with the server's conformance to RFC0959.\n"
+"     RFC 3986 to support the empty directory in the URL pathname (`//'),\n"
+"     conflicts with the server's conformance to RFC 959.\n"
 "     Try the same URL without the `//' in the URL pathname.\n"
 "\n");
                                        goto cleanup_fetch_ftp;
@@ -281,7 +281,7 @@
 
 /*
- * Parse URL of form (per RFC3986):
+ * Parse URL of form (per RFC 3986):
  *     <type>://[<user>[:<password>]@]<host>[:<port>][/<path>]
  * Returns -1 if a parse error occurred, otherwise 0.
@@ -291,7 +291,7 @@
  * the number given, or ftpport if ftp://, or httpport if http://.
  *
- * XXX: this is not totally RFC3986 compliant; <path> will have the
+ * XXX: this is not totally RFC 3986 compliant; <path> will have the
  * leading `/' unless it's an ftp:// URL, as this makes things easier
  * for file:// and http:// URLs.  ftp:// URLs have the `/' between the
@@ -1520,12 +1520,12 @@
                 *
                 * If we are dealing with an `ftp://host/path' URL
-                * (urltype is FTP_URL_T), then RFC3986 says we need to
+                * (urltype is FTP_URL_T), then RFC 3986 says we need to
                 * send a separate CWD command for each unescaped "/"
                 * in the path, and we have to interpret %hex escaping
@@ -1520,12 +1520,12 @@
                 * *after* we find the slashes.  It's possible to get
                 * empty components here, (from multiple adjacent
-                * slashes in the path) and RFC3986 says that we should
+                * slashes in the path) and RFC 3986 says that we should
                 * still do `CWD ' (with a null argument) in such cases.
                 *
diff -r 3a7e4c146eae -r 0c5508ace90c usr.bin/ftp/util.c
--- a/usr.bin/ftp/util.c        Fri Mar 05 06:47:58 2010 +0000
+++ b/usr.bin/ftp/util.c        Fri Mar 05 07:41:10 2010 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: util.c,v 1.153 2010/03/04 21:40:53 lukem Exp $ */
+/*     $NetBSD: util.c,v 1.154 2010/03/05 07:41:10 lukem Exp $ */
 
 /*-
  * Copyright (c) 1997-2009 The NetBSD Foundation, Inc.
@@ -64,7 +64,7 @@
 
 #include <sys/cdefs.h>
 #ifndef lint
-__RCSID("$NetBSD: util.c,v 1.153 2010/03/04 21:40:53 lukem Exp $");
+__RCSID("$NetBSD: util.c,v 1.154 2010/03/05 07:41:10 lukem Exp $");
 #endif /* not lint */
 
 /*
@@ -169,7 +169,7 @@
 
                        /*
                         * work-around broken ProFTPd servers that can't
-                        * even obey RFC2389.
+                        * even obey RFC 2389.
                         */
        while (*fline && isspace((int)*fline))
                fline++;
@@ -393,7 +393,7 @@
         */
        if (anonftp) {
                FREEPTR(fuser);
-               fuser = ftp_strdup("anonymous");        /* as per RFC1635 */
+               fuser = ftp_strdup("anonymous");        /* as per RFC 1635 */
                FREEPTR(pass);
                pass = ftp_strdup(getoptionvalue("anonpass"));
        }
@@ -778,7 +778,7 @@
 }
 
 /*
  * Format tm in an RFC2822 compatible manner, with a trailing \n.
  * Returns a pointer to a static string containing the result.
  */
 const char *
@@ -788,7 +788,7 @@
 
        if (strftime(result, sizeof(result),
            "%a, %d %b %Y %H:%M:%S %z\n", tm) == 0)
-               errx(1, "Can't convert RFC2822 time: buffer too small");
+               errx(1, "Can't convert RFC 2822 time: buffer too small");
        return result;
 }
 
@@ -806,9 +806,9 @@
        /* The representation of %a depends on the current locale. */
        curlocale = setlocale(LC_TIME, NULL);
        (void)setlocale(LC_TIME, "C");
-                                                               /* RFC1123 */
+                                                               /* RFC 1123 */
        if ((t = strptime(httpdate, "%a, %d %b %Y %H:%M:%S GMT", parsed)) ||
-                                                               /* RFC0850 */
+                                                               /* RFC 850 */
            (t = strptime(httpdate, "%a, %d-%b-%y %H:%M:%S GMT", parsed)) ||
                                                                /* asctime */
            (t = strptime(httpdate, "%a, %b %d %H:%M:%S %Y", parsed))) {
@@ -778,7 +778,7 @@
 
 /*
- * Format tm in an RFC2822 compatible manner, with a trailing \n.
+ * Format tm in an RFC 2822 compatible manner, with a trailing \n.
  * Returns a pointer to a static string containing the result.
  */



Home | Main Index | Thread Index | Old Index